aboutsummaryrefslogtreecommitdiffstats
path: root/googlemock/test/gmock-nice-strict_test.cc
diff options
context:
space:
mode:
authorGennadiy Civil <gennadiycivil@users.noreply.github.com>2017-08-20 15:15:31 -0400
committerGitHub <noreply@github.com>2017-08-20 15:15:31 -0400
commit026735daf34cf180e34a976b3167cc4b311e3f11 (patch)
tree070d9a0cc1ac4bfdb3ec8572196a1a02bb8480c1 /googlemock/test/gmock-nice-strict_test.cc
parent35737ac7ac1a3bde0dbec193825361336abb2222 (diff)
downloadgoogletest-026735daf34cf180e34a976b3167cc4b311e3f11.tar.gz
googletest-026735daf34cf180e34a976b3167cc4b311e3f11.tar.bz2
googletest-026735daf34cf180e34a976b3167cc4b311e3f11.zip
Proposing these changes, please review
Slightly better names and cleaner tests. Please review
Diffstat (limited to 'googlemock/test/gmock-nice-strict_test.cc')
-rw-r--r--googlemock/test/gmock-nice-strict_test.cc21
1 files changed, 9 insertions, 12 deletions
diff --git a/googlemock/test/gmock-nice-strict_test.cc b/googlemock/test/gmock-nice-strict_test.cc
index a8032e24..2cb0a96d 100644
--- a/googlemock/test/gmock-nice-strict_test.cc
+++ b/googlemock/test/gmock-nice-strict_test.cc
@@ -62,10 +62,10 @@ using testing::internal::CaptureStdout;
using testing::internal::GetCapturedStdout;
#endif
-// Dummy class without default constructor.
-class Dummy {
+// Class without default constructor.
+class NotDefaultConstructible {
public:
- Dummy(int) {}
+ NotDefaultConstructible(int) {}
};
// Defines some mock classes needed by the tests.
@@ -85,7 +85,7 @@ class MockFoo : public Foo {
MOCK_METHOD0(DoThis, void());
MOCK_METHOD1(DoThat, int(bool flag));
- MOCK_METHOD0(ReturnSomething, Dummy());
+ MOCK_METHOD0(ReturnNonDefaultConstructible, NotDefaultConstructible());
private:
GTEST_DISALLOW_COPY_AND_ASSIGN_(MockFoo);
@@ -214,23 +214,20 @@ TEST(NiceMockTest, AllowsExpectedCall) {
nice_foo.DoThis();
}
// Tests that an unexpected call on a nice mock which returns a non-built in
// default value throws an exception and the exception contains the name of
// the method.
TEST(NiceMockTest, ThrowsExceptionForUnknownReturnTypes) {
NiceMock<MockFoo> nice_foo;
#if GTEST_HAS_EXCEPTIONS
try {
- nice_foo.ReturnSomething();
+ nice_foo.ReturnNonDefaultConstructible();
FAIL();
} catch (const std::runtime_error& ex) {
const std::string exception_msg(ex.what());
- EXPECT_NE(exception_msg.find("ReturnSomething"), std::string::npos);
+ EXPECT_THAT(ex.what(), HasSubstr("ReturnNonDefaultConstructible"));
}
#else
- EXPECT_DEATH_IF_SUPPORTED({
- nice_foo.ReturnSomething();
- }, "");
+ EXPECT_DEATH_IF_SUPPORTED({ nice_foo.ReturnNonDefaultConstructible(); }, "");
#endif
}
@@ -214,23 +214,20 @@ TEST(NiceMockTest, AllowsExpectedCall) {
nice_foo.DoThis();
}
-// Tests that an unexpected call on a nice mock which returns a non-built in
-// default value throws an exception and the exception contains the name of
-// the method.
+// Tests that an unexpected call on a nice mock which returns a not-default-constructible
+// type throws an exception and the exception contains the method's name.
TEST(NiceMockTest, ThrowsExceptionForUnknownReturnTypes) {
NiceMock<MockFoo> nice_foo;